@@ -3,6 +3,7 @@
 package ErrorTest;
 use strict;
 use base qw( Data::ObjectDriver::BaseObject );
+use DodTestUtil;
 
 use Data::ObjectDriver::Driver::DBI;
 
@@ -11,6 +12,6 @@ __PACKAGE__->install_properties({
     datasource => 'error_test',
     primary_key =>  [ ],
     driver => Data::ObjectDriver::Driver::DBI->new(
-        dsn      => 'dbi:SQLite:dbname=global.db',
+        dsn      => DodTestUtil::dsn('global'),
     ),
 });
