@@ -1,8 +1,9 @@
-# $Id: Ingredient.pm 1054 2005-12-13 07:58:53Z btrott $
+# $Id$
 
 package Ingredient;
 use strict;
 use base qw( Data::ObjectDriver::BaseObject );
+use DodTestUtil;
 
 use Data::ObjectDriver::Driver::DBI;
 
@@ -13,7 +14,7 @@ __PACKAGE__->install_properties({
     datasource => 'ingredients',
     primary_key => 'id',
     driver      => Data::ObjectDriver::Driver::DBI->new(
-            dsn      => 'dbi:SQLite:dbname=global.db',
+            dsn      => DodTestUtil::dsn('global'),
             pk_generator => \&generate_pk,
     ),
 });
